<template>
  <!--UI上下文的展示器-->
  <div style="height:calc(100% - 4px);min-width:1200px" >
    <el-header v-if="uiDefineVO.northAreas && uiDefineVO.northAreas.length>0">
      <UIContentArea :key="'northArea-'+uiDefineVO.oid"
                     :uiBtmType="btmType"
                     :uiContext="context"
                     :areasData="uiDefineVO.northAreas"
                     :dataStore="checkedData.northArea.data"
                     :inDialog="inDialog"
                     :sourceData="sourceData"
                     :sourceBtmType="btmType"
                     areas-name="northArea"
                     @setDataStore="setDataStore">
      </UIContentArea>
    </el-header>
    <el-container
      :style="'height: '+(uiDefineVO.northAreas && uiDefineVO.northAreas.length>0?'calc(100% - 70px)':'100%')">
      <el-aside v-if="uiDefineVO.westAreas && uiDefineVO.westAreas.length>0"
                :width="uiDefineVO.westAreas[0].componentVOs[0].uiComponentType=='table' || uiDefineVO.westAreas[0].componentVOs[0].uiComponentType=='TreeTable'?'420px':'320px'"
                height="100%">
        <UIContentArea :key="'westArea-'+uiDefineVO.oid"
                       :uiBtmType="btmType"
                       :uiContext="context"
                       :areasData="uiDefineVO.westAreas"
                       :dataStore="checkedData.westArea.data"
                       :inDialog="inDialog"
                       :sourceData="sourceData"
                       :sourceBtmType="btmType"
                       areas-name="westArea"
                       cradStyle=""
                       @setDataStore="setDataStore">
        </UIContentArea>
      </el-aside>
      <el-container style="height: 100%;display: block">
        <el-main v-if="uiDefineVO.centerAreas && uiDefineVO.centerAreas.length>0" :style="'min-height: 300px;height: '+centerHeight">
          <UIContentArea :key="'centerArea-'+uiDefineVO.oid"
                         :uiBtmType="btmType"
                         :uiContext="context"
                         :areasData="uiDefineVO.centerAreas"
                         :dataStore="checkedData.centerArea.data"
                         :inDialog="inDialog"
                         :sourceData="checkedData.westArea.data[checkedData.westArea.data.length-1]"
                         :sourceBtmType="checkedData.westArea.DefineVOBtmType"
                         areas-name="centerArea"
                         cradStyle=""
                         @setDataStore="setDataStore">
          </UIContentArea>
        </el-main>
        <el-footer v-if="uiDefineVO.southAreas && uiDefineVO.southAreas.length>0" height="35%"
                   style="min-height: 150px;">
          <UIContentArea :key="'southArea-'+uiDefineVO.oid"
                         :uiBtmType="btmType"
                         :uiContext="context"
                         :areasData="uiDefineVO.southAreas"
                         :dataStore="checkedData.southArea.data"
                         :inDialog="inDialog"
                         :sourceData="checkedData.centerArea.data[checkedData.centerArea.data.length-1]"
                         :sourceBtmType="checkedData.centerArea.DefineVOBtmType"
                         areas-name="southArea"
                         cradStyle=""
                         @setDataStore="setDataStore">
          </UIContentArea>
        </el-footer>
      </el-container>
    </el-container>
  </div>
</template>

<script>
import {verifyNull} from "@/util/validate";
import UIContentArea from "@/views/base/UIContentArea"
import {getUIContext} from '@/api/base/ui'

export default {
  name: "UIContentViewer",
  components: {UIContentArea},
  data() {
    return {
      btmType: '',//业务类型（或链接类型）
      context: '',//UI上下文的名称
      checkedData: {
        //各区域选中数据
        northArea: {
          DefineVOBtmType:'',
          data:[{}]
        },
        westArea: {
          DefineVOBtmType:'',
          data:[{}]
        },
        centerArea: {
          DefineVOBtmType:'',
          data:[{}]
        },
        southArea: {
          DefineVOBtmType:'',
          data:[{}]
        }
      },
      uiDefineVO: {},
      centerHeight: '100%',
      inDialog: false,
      //菜单源数据
      sourceData: {},
    }
  },
  watch: {
    $route(to, from) {
      this.getTheParameters()
      this.initUI();
    }
  },
  computed: {
    typeAndContext(){
      return this.btmType+this.context;
    }
  },
  created() {
    console.log(this.$route);
    if (verifyNull(this.$route.query.type) || (verifyNull(this.$route.query.context) && verifyNull(this.$route.query.content))) {
      this.$message.error("配置的信息错误，请参考“?type=xxx&context=yyy&param=zzz”这种形式。其中type是业务类型（或链接类型），context是UI上下文的名称");
      return false;
    }
    this.getTheParameters()
    this.initUI();
  },
  methods: {
    getTheParameters(){
      this.btmType = this.$route.query.type;
      this.context = this.$route.query.context || this.$route.query.content;
      this.sourceData = this.$route.query;
    },
    initUI() {
      getUIContext({btmType: this.btmType, id: this.context}).then(res => {
        this.uiDefineVO = res.data.obj;
        this.initContext();
      })
    },
    initContext() {
      if (this.uiDefineVO.southAreas && this.uiDefineVO.southAreas.length > 0) {
        this.centerHeight = '65%';
      } else {
        this.centerHeight = '100%';
      }
    },
    setDataStore(value) {
      this.checkedData[value.area].DefineVOBtmType = value.btmType;
      this.checkedData[value.area].data = value.dataStore;
    }
  }
}
</script>

<style scoped>
.el-container {
  padding: 0 !important;
}

.el-header, .el-aside, .el-main, .el-footer {
  padding: 0;
}

.el-header {
  margin-bottom: 10px;
}
</style>
